@@ -1,4 +1,3 @@
-import pprint
 from dez.http.application import HTTPApplication
 
 def simple_app(environ, start_response):
@@ -6,7 +5,7 @@ def simple_app(environ, start_response):
     print environ['wsgi.input'].read()
     return []
     
-def main(port):
-    httpd = HTTPApplication("127.0.0.1", port)
+def main(**kwargs):
+    httpd = HTTPApplication(kwargs['domain'], kwargs['port'])
     httpd.add_wsgi_rule("/", simple_app)
     httpd.start()
